==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/servicenetworking/kotlin/outputs/GetTrafficControllerInterfaceResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicenetworking.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 * Concrete tracked resource types can be created by aliasing this type using a specific property type.
 * @property associations Associations References List
 * @property configurationEndpoints Configuration Endpoints.
 * @property frontends Frontends References List
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property location The geo-location where the resource lives
 * @property name The name of the resource
 * @property provisioningState The status of the last operation.
 * @property systemData Azure Resource Manager metadata containing createdBy and modifiedBy information.
 * @property tags Resource tags.
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class GetTrafficControllerInterfaceResult(
    public val associations: List<ResourceIdResponse>,
    public val configurationEndpoints: List<String>,
    public val frontends: List<ResourceIdResponse>,
    public val id: String,
    public val location: String,
    public val name: String,
    public val provisioningState: String,
    public val systemData: SystemDataResponse,
    public val tags: Map<String, String>? = null,
    public val type: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.servicenetworking.outputs.GetTrafficControllerInterfaceResult):
            GetTrafficControllerInterfaceResult = GetTrafficControllerInterfaceResult(
            associations = javaType.associations().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.servicenetworking.kotlin.outputs.ResourceIdResponse.Companion.toKotlin(args0)
                })
            }),
            configurationEndpoints = javaType.configurationEndpoints().map({ args0 -> args0 }),
            frontends = javaType.frontends().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.servicenetworking.kotlin.outputs.ResourceIdResponse.Companion.toKotlin(args0)
                })
            }),
            id = javaType.id(),
            location = javaType.location(),
            name = javaType.name(),
            provisioningState = javaType.provisioningState(),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.servicenetworking.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            tags = javaType.tags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            type = javaType.type(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/servicenetworking/kotlin/outputs/GetTrafficControllerInterfaceResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicenetworking.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 * Concrete tracked resource types can be created by aliasing this type using a specific property type.
 * @property associations Associations References List
 * @property configurationEndpoints Configuration Endpoints.
 * @property frontends Frontends References List
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property location The geo-location where the resource lives
 * @property name The name of the resource
 * @property provisioningState The status of the last operation.
 * @property systemData Azure Resource Manager metadata containing createdBy and modifiedBy information.
 * @property tags Resource tags.
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class GetTrafficControllerInterfaceResult(
    public val associations: List<ResourceIdResponse>,
    public val configurationEndpoints: List<String>,
    public val frontends: List<ResourceIdResponse>,
    public val id: String,
    public val location: String,
    public val name: String,
    public val provisioningState: String,
    public val systemData: SystemDataResponse,
    public val tags: Map<String, String>? = null,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.servicenetworking.outputs.GetTrafficControllerInterfaceResult): GetTrafficControllerInterfaceResult = GetTrafficControllerInterfaceResult(
            associations = javaType.associations().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.servicenetworking.kotlin.outputs.ResourceIdResponse.Companion.toKotlin(args0)
                })
            }),
            configurationEndpoints = javaType.configurationEndpoints().map({ args0 -> args0 }),
            frontends = javaType.frontends().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.servicenetworking.kotlin.outputs.ResourceIdResponse.Companion.toKotlin(args0)
                })
            }),
            id = javaType.id(),
            location = javaType.location(),
            name = javaType.name(),
            provisioningState = javaType.provisioningState(),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.servicenetworking.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            tags = javaType.tags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            type = javaType.type(),
        )
    }
}
